"use client"

import { useState, useEffect } from "react"
import { useAuth } from "@/context/auth-context"
import { Card, CardContent, CardDescription, CardHeader, CardTitle } from "@/components/ui/card"
import { Tabs, TabsContent, TabsList, TabsTrigger } from "@/components/ui/tabs"
import { LineChart, Line, XAxis, YAxis, CartesianGrid, Tooltip, Legend, ResponsiveContainer } from "recharts"
import {
  User,
  Mail,
  Phone,
  MapPin,
  Calendar,
  Award,
  BookOpen,
  TestTube,
  Clock,
  CheckCircle,
  XCircle,
  CreditCard,
  AlertTriangle,
} from "lucide-react"
import { Progress } from "@/components/ui/progress"
import Link from "next/link"
import { Button } from "@/components/ui/button"

type Score = {
  id: number
  examType: string
  examId: string
  score: number
  maxScore: number
  passedAt: string
}

type UserProfile = {
  id: number
  username: string
  name: string
  email: string | null
  role: string
  planType: string
  expirationDate: string | null
  createdAt: string
  profile: {
    id: number
    address: string | null
    phone: string | null
    birthDate: string | null
  } | null
  scores: Score[]
}

export default function ProfilePage() {
  const { user, isLoading } = useAuth()
  const [userProfile, setUserProfile] = useState<UserProfile | null>(null)
  const [isProfileLoading, setIsProfileLoading] = useState(true)

  // Ajouter un état pour suivre si le code s'exécute côté client
  const [isClient, setIsClient] = useState(false)

  // Ajouter cet useEffect au début du composant, juste après les déclarations d'état
  useEffect(() => {
    setIsClient(true)
  }, [])

  useEffect(() => {
    const fetchUserProfile = async () => {
      if (!user) return

      try {
        setIsProfileLoading(true)
        const response = await fetch(`/api/users/${user.id}`)

        if (!response.ok) {
          throw new Error("Failed to fetch user profile")
        }

        const profileData = await response.json()
        setUserProfile(profileData)
      } catch (error) {
        console.error("Error fetching user profile:", error)
      } finally {
        setIsProfileLoading(false)
      }
    }

    if (user) {
      fetchUserProfile()
    }
  }, [user])

  if (isLoading || isProfileLoading) {
    return (
      <div className="min-h-screen flex items-center justify-center bg-gray-50">
        <div className="animate-spin rounded-full h-12 w-12 border-t-2 border-b-2 border-orange-500"></div>
      </div>
    )
  }

  if (!user || !userProfile) {
    return null
  }

  // Format the expiration date
  const formatDate = (dateString: string | null) => {
    if (!dateString) return "Non définie"
    return new Date(dateString).toLocaleDateString()
  }

  // Check if subscription is about to expire (within 7 days)
  const isSubscriptionExpiringSoon = () => {
    if (!userProfile.expirationDate) return false
    const expirationDate = new Date(userProfile.expirationDate)
    const today = new Date()
    const diffTime = expirationDate.getTime() - today.getTime()
    const diffDays = Math.ceil(diffTime / (1000 * 60 * 60 * 24))
    return diffDays <= 7 && diffDays > 0
  }

  // Get plan type display name
  const getPlanTypeName = (planType: string) => {
    switch (planType) {
      case "free":
        return "Gratuit"
      case "basic":
        return "Basique"
      case "premium":
        return "Premium"
      default:
        return planType
    }
  }

  // Get plan type color
  const getPlanTypeColor = (planType: string) => {
    switch (planType) {
      case "free":
        return "bg-gray-100 text-gray-800"
      case "basic":
        return "bg-blue-100 text-blue-800"
      case "premium":
        return "bg-purple-100 text-purple-800"
      default:
        return "bg-gray-100 text-gray-800"
    }
  }

  // Préparer les données pour les graphiques
  const examScores = userProfile.scores.filter((score) => score.examType === "exam")
  const exerciseScores = userProfile.scores.filter((score) => score.examType === "exercise")

  const scoreHistory = userProfile.scores.map((score) => ({
    date: new Date(score.passedAt).toLocaleDateString(),
    percentage: Math.round((score.score / score.maxScore) * 100),
    type: score.examType === "exam" ? "Examen" : "Exercice",
  }))

  return (
    <div className="min-h-screen bg-gray-50">
      <div className="bg-sky-500 py-16 px-4">
        <div className="container mx-auto">
          <h1 className="text-4xl font-bold text-gray-900 mb-2">Mon Profil</h1>
          <p className="text-xl text-gray-800">Consultez vos informations personnelles et vos statistiques</p>
        </div>
      </div>

      <div className="container mx-auto py-12 px-4">
        <div className="grid grid-cols-1 md:grid-cols-3 gap-8 mb-12">
          <Card className="md:col-span-1 shadow-lg">
            <CardHeader className="pb-2">
              <CardTitle className="text-2xl flex items-center">
                <User className="mr-2 h-6 w-6 text-orange-500" />
                Informations personnelles
              </CardTitle>
              <CardDescription>Vos informations de compte</CardDescription>
            </CardHeader>
            <CardContent className="space-y-6 pt-6">
              <div className="flex items-center">
                <User className="h-5 w-5 text-gray-500 mr-3" />
                <div>
                  <p className="text-sm text-gray-500">Nom</p>
                  <p className="font-medium">{userProfile.name}</p>
                </div>
              </div>

              <div className="flex items-center">
                <Mail className="h-5 w-5 text-gray-500 mr-3" />
                <div>
                  <p className="text-sm text-gray-500">Email</p>
                  <p className="font-medium">{userProfile.email || "Non renseigné"}</p>
                </div>
              </div>

              {userProfile.profile && (
                <>
                  <div className="flex items-center">
                    <Phone className="h-5 w-5 text-gray-500 mr-3" />
                    <div>
                      <p className="text-sm text-gray-500">Téléphone</p>
                      <p className="font-medium">{userProfile.profile.phone || "Non renseigné"}</p>
                    </div>
                  </div>

                  <div className="flex items-center">
                    <MapPin className="h-5 w-5 text-gray-500 mr-3" />
                    <div>
                      <p className="text-sm text-gray-500">Adresse</p>
                      <p className="font-medium">{userProfile.profile.address || "Non renseignée"}</p>
                    </div>
                  </div>

                  <div className="flex items-center">
                    <Calendar className="h-5 w-5 text-gray-500 mr-3" />
                    <div>
                      <p className="text-sm text-gray-500">Date de naissance</p>
                      <p className="font-medium">
                        {userProfile.profile.birthDate
                          ? new Date(userProfile.profile.birthDate).toLocaleDateString()
                          : "Non renseignée"}
                      </p>
                    </div>
                  </div>
                </>
              )}

              <div className="flex items-center">
                <Award className="h-5 w-5 text-gray-500 mr-3" />
                <div>
                  <p className="text-sm text-gray-500">Membre depuis</p>
                  <p className="font-medium">{new Date(userProfile.createdAt).toLocaleDateString()}</p>
                </div>
              </div>

              <div className="border-t border-gray-200 pt-4 mt-4">
                <h3 className="font-semibold text-lg mb-4">Informations d'abonnement</h3>

                <div className="flex items-center mb-4">
                  <CreditCard className="h-5 w-5 text-gray-500 mr-3" />
                  <div>
                    <p className="text-sm text-gray-500">Type d'abonnement</p>
                    <span
                      className={`px-2 py-1 rounded-full text-xs font-medium ${getPlanTypeColor(userProfile.planType)}`}
                    >
                      {getPlanTypeName(userProfile.planType)}
                    </span>
                  </div>
                </div>

                <div className="flex items-center">
                  <Calendar className="h-5 w-5 text-gray-500 mr-3" />
                  <div>
                    <p className="text-sm text-gray-500">Date d'expiration</p>
                    <p className="font-medium">{formatDate(userProfile.expirationDate)}</p>
                  </div>
                </div>

                {isSubscriptionExpiringSoon() && (
                  <div className="mt-4 bg-yellow-50 border-l-4 border-yellow-400 p-4 rounded-r">
                    <div className="flex">
                      <AlertTriangle className="h-5 w-5 text-yellow-400 mr-2" />
                      <div>
                        <p className="font-medium text-yellow-700">Abonnement expirant bientôt</p>
                        <p className="text-sm text-yellow-600">
                          Votre abonnement expire le {formatDate(userProfile.expirationDate)}. Pensez à le renouveler.
                        </p>
                        <Link href="/subscription">
                          <Button className="mt-2 bg-yellow-500 hover:bg-yellow-600 text-white">
                            Renouveler mon abonnement
                          </Button>
                        </Link>
                      </div>
                    </div>
                  </div>
                )}
              </div>
            </CardContent>
          </Card>

          <Card className="md:col-span-2 shadow-lg">
            <CardHeader className="pb-2">
              <CardTitle className="text-2xl flex items-center">
                <Award className="mr-2 h-6 w-6 text-orange-500" />
                Statistiques
              </CardTitle>
              <CardDescription>Vos performances sur la plateforme</CardDescription>
            </CardHeader>
            <CardContent className="pt-6">
              <div className="grid grid-cols-1 md:grid-cols-3 gap-6 mb-8">
                <div className="bg-blue-50 rounded-lg p-6 border border-blue-100">
                  <div className="flex items-center mb-3">
                    <div className="w-10 h-10 rounded-full bg-blue-100 flex items-center justify-center mr-3">
                      <Award className="h-5 w-5 text-blue-600" />
                    </div>
                    <h3 className="font-medium text-lg">Score moyen</h3>
                  </div>
                  <p className="text-3xl font-bold text-blue-600">
                    {userProfile.scores.length > 0
                      ? Math.round(
                          userProfile.scores.reduce((acc, curr) => acc + (curr.score / curr.maxScore) * 100, 0) /
                            userProfile.scores.length,
                        )
                      : 0}
                    %
                  </p>
                </div>

                <div className="bg-red-50 rounded-lg p-6 border border-red-100">
                  <div className="flex items-center mb-3">
                    <div className="w-10 h-10 rounded-full bg-red-100 flex items-center justify-center mr-3">
                      <TestTube className="h-5 w-5 text-red-600" />
                    </div>
                    <h3 className="font-medium text-lg">Examens passés</h3>
                  </div>
                  <p className="text-3xl font-bold text-red-600">{examScores.length}</p>
                </div>

                <div className="bg-green-50 rounded-lg p-6 border border-green-100">
                  <div className="flex items-center mb-3">
                    <div className="w-10 h-10 rounded-full bg-green-100 flex items-center justify-center mr-3">
                      <BookOpen className="h-5 w-5 text-green-600" />
                    </div>
                    <h3 className="font-medium text-lg">Exercices complétés</h3>
                  </div>
                  <p className="text-3xl font-bold text-green-600">{exerciseScores.length}</p>
                </div>
              </div>

              <div className="h-72 bg-white p-4 rounded-lg border border-gray-200">
                <h3 className="text-lg font-medium mb-4">Évolution de vos scores</h3>
                <ResponsiveContainer width="100%" height="100%">
                  <LineChart data={scoreHistory} margin={{ top: 5, right: 30, left: 20, bottom: 5 }}>
                    <CartesianGrid strokeDasharray="3 3" />
                    <XAxis dataKey="date" />
                    <YAxis domain={[0, 100]} />
                    <Tooltip formatter={(value) => [`${value}%`, "Score"]} />
                    <Legend />
                    <Line
                      type="monotone"
                      dataKey="percentage"
                      name="Score (%)"
                      stroke="#F97316"
                      activeDot={{ r: 8 }}
                      strokeWidth={2}
                    />
                  </LineChart>
                </ResponsiveContainer>
              </div>
            </CardContent>
          </Card>
        </div>

        <Tabs defaultValue="all" className="space-y-6">
          <TabsList className="bg-white shadow-md">
            <TabsTrigger value="all" className="data-[state=active]:bg-orange-100 data-[state=active]:text-orange-700">
              Tous les tests
            </TabsTrigger>
            <TabsTrigger
              value="exams"
              className="data-[state=active]:bg-orange-100 data-[state=active]:text-orange-700"
            >
              Examens
            </TabsTrigger>
            <TabsTrigger
              value="exercises"
              className="data-[state=active]:bg-orange-100 data-[state=active]:text-orange-700"
            >
              Exercices
            </TabsTrigger>
          </TabsList>

          <TabsContent value="all">
            <Card className="shadow-lg">
              <CardHeader className="pb-2">
                <CardTitle className="text-2xl flex items-center">
                  <Clock className="mr-2 h-6 w-6 text-orange-500" />
                  Historique des tests
                </CardTitle>
                <CardDescription>Tous les tests que vous avez passés</CardDescription>
              </CardHeader>
              <CardContent className="pt-6">
                <div className="overflow-x-auto">
                  <table className="w-full border-collapse">
                    <thead>
                      <tr className="bg-gray-50">
                        <th className="text-left py-3 px-4 font-medium text-gray-500">Date</th>
                        <th className="text-left py-3 px-4 font-medium text-gray-500">Type</th>
                        <th className="text-left py-3 px-4 font-medium text-gray-500">ID</th>
                        <th className="text-left py-3 px-4 font-medium text-gray-500">Score</th>
                        <th className="text-left py-3 px-4 font-medium text-gray-500">Pourcentage</th>
                        <th className="text-left py-3 px-4 font-medium text-gray-500">Résultat</th>
                      </tr>
                    </thead>
                    <tbody className="divide-y divide-gray-200">
                      {userProfile.scores.length === 0 ? (
                        <tr>
                          <td colSpan={6} className="py-8 text-center text-gray-500">
                            Vous n'avez pas encore passé de test
                          </td>
                        </tr>
                      ) : (
                        userProfile.scores.map((score) => {
                          const percentage = Math.round((score.score / score.maxScore) * 100)
                          const isPassed = percentage >= 70

                          return (
                            <tr key={score.id} className="hover:bg-gray-50">
                              <td className="py-4 px-4">{new Date(score.passedAt).toLocaleString()}</td>
                              <td className="py-4 px-4">
                                <span
                                  className={`px-2 py-1 rounded-full text-xs font-medium ${
                                    score.examType === "exam" ? "bg-red-100 text-red-700" : "bg-blue-100 text-blue-700"
                                  }`}
                                >
                                  {score.examType === "exam" ? "Examen" : "Exercice"}
                                </span>
                              </td>
                              <td className="py-4 px-4">{score.examId}</td>
                              <td className="py-4 px-4">
                                {score.score} / {score.maxScore}
                              </td>
                              <td className="py-4 px-4">
                                <div className="flex items-center">
                                  <div className="w-full bg-gray-200 rounded-full h-2.5 mr-2 max-w-32">
                                    <div
                                      className={`h-2.5 rounded-full ${
                                        percentage >= 80
                                          ? "bg-green-500"
                                          : percentage >= 50
                                            ? "bg-yellow-500"
                                            : "bg-red-500"
                                      }`}
                                      style={{ width: `${percentage}%` }}
                                    ></div>
                                  </div>
                                  <span>{percentage}%</span>
                                </div>
                              </td>
                              <td className="py-4 px-4">
                                {isPassed ? (
                                  <div className="flex items-center text-green-600">
                                    <CheckCircle className="h-5 w-5 mr-1" />
                                    <span>Réussi</span>
                                  </div>
                                ) : (
                                  <div className="flex items-center text-red-600">
                                    <XCircle className="h-5 w-5 mr-1" />
                                    <span>Échoué</span>
                                  </div>
                                )}
                              </td>
                            </tr>
                          )
                        })
                      )}
                    </tbody>
                  </table>
                </div>
              </CardContent>
            </Card>
          </TabsContent>

          <TabsContent value="exams">
            <Card className="shadow-lg">
              <CardHeader className="pb-2">
                <CardTitle className="text-2xl flex items-center">
                  <TestTube className="mr-2 h-6 w-6 text-red-500" />
                  Examens
                </CardTitle>
                <CardDescription>Historique de vos examens</CardDescription>
              </CardHeader>
              <CardContent className="pt-6">
                {examScores.length === 0 ? (
                  <div className="py-8 text-center text-gray-500">Vous n'avez pas encore passé d'examen</div>
                ) : (
                  <div className="grid grid-cols-1 md:grid-cols-2 gap-6">
                    {examScores.map((score) => {
                      const percentage = Math.round((score.score / score.maxScore) * 100)
                      const isPassed = percentage >= 70

                      return (
                        <Card
                          key={score.id}
                          className={`border-l-4 ${isPassed ? "border-l-green-500" : "border-l-red-500"}`}
                        >
                          <CardContent className="p-6">
                            <div className="flex justify-between items-start mb-4">
                              <div>
                                <h3 className="font-semibold text-lg">Examen: {score.examId}</h3>
                                <p className="text-gray-500 text-sm">
                                  {new Date(score.passedAt).toLocaleDateString()} à{" "}
                                  {new Date(score.passedAt).toLocaleTimeString()}
                                </p>
                              </div>
                              {isPassed ? (
                                <div className="bg-green-100 text-green-700 px-3 py-1 rounded-full text-sm font-medium">
                                  Réussi
                                </div>
                              ) : (
                                <div className="bg-red-100 text-red-700 px-3 py-1 rounded-full text-sm font-medium">
                                  Échoué
                                </div>
                              )}
                            </div>

                            <div className="mb-4">
                              <div className="flex justify-between text-sm mb-1">
                                <span>
                                  Score: {score.score}/{score.maxScore}
                                </span>
                                <span>{percentage}%</span>
                              </div>
                              <Progress
                                value={percentage}
                                className="h-2"
                                indicatorClassName={
                                  percentage >= 80 ? "bg-green-500" : percentage >= 50 ? "bg-yellow-500" : "bg-red-500"
                                }
                              />
                            </div>
                          </CardContent>
                        </Card>
                      )
                    })}
                  </div>
                )}
              </CardContent>
            </Card>
          </TabsContent>

          <TabsContent value="exercises">
            <Card className="shadow-lg">
              <CardHeader className="pb-2">
                <CardTitle className="text-2xl flex items-center">
                  <BookOpen className="mr-2 h-6 w-6 text-blue-500" />
                  Exercices
                </CardTitle>
                <CardDescription>Historique de vos exercices</CardDescription>
              </CardHeader>
              <CardContent className="pt-6">
                {exerciseScores.length === 0 ? (
                  <div className="py-8 text-center text-gray-500">Vous n'avez pas encore fait d'exercice</div>
                ) : (
                  <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-6">
                    {exerciseScores.map((score) => {
                      const percentage = Math.round((score.score / score.maxScore) * 100)

                      return (
                        <Card key={score.id} className="hover:shadow-md transition-shadow">
                          <CardContent className="p-4">
                            <div className="flex items-center mb-3">
                              <div
                                className={`w-10 h-10 rounded-full flex items-center justify-center mr-3 ${
                                  percentage >= 80
                                    ? "bg-green-100 text-green-600"
                                    : percentage >= 50
                                      ? "bg-yellow-100 text-yellow-600"
                                      : "bg-red-100 text-red-600"
                                }`}
                              >
                                {percentage}%
                              </div>
                              <div>
                                <h3 className="font-medium">Exercice: {score.examId}</h3>
                                <p className="text-gray-500 text-sm">{new Date(score.passedAt).toLocaleDateString()}</p>
                              </div>
                            </div>

                            <div className="text-sm text-gray-600">
                              Score: {score.score}/{score.maxScore}
                            </div>
                          </CardContent>
                        </Card>
                      )
                    })}
                  </div>
                )}
              </CardContent>
            </Card>
          </TabsContent>
        </Tabs>
      </div>
    </div>
  )
}
